commit bc358e86aceb79376e59f437e760fabf5eac7827
Author: Susan Douglas <susan.douglas@enterprisedb.com>
Date:   Fri May 20 07:58:34 2016 -0400

    Renaming files from create_xxx to xxx

diff --git a/docs/en_US/cast.rst b/docs/en_US/cast.rst
new file mode 100644
index 0000000..df3d9bb
--- /dev/null
+++ b/docs/en_US/cast.rst
@@ -0,0 +1,50 @@
+.. _create_cast:
+
+*************
+Create - Cast
+*************
+
+Use the *Create - Cast* dialog to define a cast. A cast specifies how to convert a value from one data type to another.
+
+The *Create - Cast* dialog allows you to implement options of the *CREATE CAST* command. For more information about the *CREATE CAST* command, see the PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/current/static/sql-createcast.html
+
+The *Create - Cast* dialog organizes the development of a cast through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_cast_general.png
+
+Use the fields in the *General* tab to identify the cast:
+
+* The *Name* field is disabled. The name that will be displayed in the tree control is the *Source* type concatenated with the *Target* type, and is generated automatically when you make selections on the *Create - Cast* *Definition* tab. 
+* Store notes about the cast in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_cast_definition.png
+
+Use the fields in the *Definition* tab to define parameters:
+
+* Use the drop-down listbox next to *Source type* to select the name of the source data type of the cast.
+* Use the drop-down listbox next to *Target type* to select the name of the target data type of the cast.
+* Use the drop-down listbox next to *Function* to select the function used to perform the cast. The function's result data type must match the target type of the cast.
+* Slide the *Context* switch to the *Implicit* position if the cast is implicit. By default, a cast can be invoked only by an explicit cast request. If the cast is marked *Implicit* then it can be invoked implicitly in any context, whether assignment or internally in an expression.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_cast_sql.png
+
+Your entries in the *Create - Cast* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Cast* dialog:
+
+.. image:: images/create_cast_sql_example.png
+
diff --git a/docs/en_US/collation.rst b/docs/en_US/collation.rst
new file mode 100644
index 0000000..b677b3f
--- /dev/null
+++ b/docs/en_US/collation.rst
@@ -0,0 +1,59 @@
+.. _create_collation:
+
+******************
+Create - Collation 
+******************
+
+
+Use the *Create - Collation* dialog to define a collation. To be able to create a collation, you must have a CREATE privilege on the destination schema.
+
+The *Create - Collation* dialog allows you to implement options of the CREATE COLLATION command. For more information about the CREATE COLLATION command, see the documentation available at:
+
+   http://www.postgresql.org/docs/current/static/sql-createcollation.html
+
+The *Create - Collation* dialog organizes the development of a collation through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_collation_general.png
+
+Use the fields in the *General* tab to identify the collation:
+
+* Use the *Name* field to add a name for the collation. The collation name must be unique within a schema. The name will be displayed in the *pgAdmin* tree control.
+* Select the name of the owner from the drop-down listbox in the *Owner* field.
+* Select the name of the schema in which the collation will reside from the drop-down listbox in the *Schema* field.
+* Store notes about the collation in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_collation_definition.png
+
+Use the fields in the *Definition* tab to specify operating system locale settings: 
+
+* Use the drop-down listbox next to *Copy collation* to select the name of an existing collation to copy. The new collation will have the same properties as the existing one, but will be an independent object. If you choose to copy an existing collation, you cannot modify the collation properties displayed on this tab.
+* Use the *Locale* field to specify a locale; a locale specifies language and language formatting characteristics. If you specify this, you cannot specify either of the following parameters. To view a list of locales supported by your Linux system use the command *locale -a*.
+* Use the *LC_COLLATE* field to specify a locale with specified string sort order. The locale must be applicable to the current database encoding. (See CREATE DATABASE for details.) 
+* Use the *LC_CTYPE* field to specify a locale with specified character classification. The locale must be applicable to the current database encoding. (See CREATE DATABASE for details.) 
+
+
+For more information about setting a locale, see Chapter 22.1 Locale Support of the PostgreSQL core documentation:
+   
+   http://www.postgresql.org/docs/9.5/static/locale.html
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_collation_sql.png
+
+Your entries in the *Create - Collation* dialog generate a generate a SQL command. The example shown demonstrates creating a collation named *french* that uses the rules specified for the locale, *fr_FR.utf8.  The collation is owned by *enterprisedb*.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Database* dialog: 
+
+.. image:: images/create_collation_sql_example.png
+
+
diff --git a/docs/en_US/create_cast.rst b/docs/en_US/create_cast.rst
deleted file mode 100644
index df3d9bb..0000000
--- a/docs/en_US/create_cast.rst
+++ /dev/null
@@ -1,50 +0,0 @@
-.. _create_cast:
-
-*************
-Create - Cast
-*************
-
-Use the *Create - Cast* dialog to define a cast. A cast specifies how to convert a value from one data type to another.
-
-The *Create - Cast* dialog allows you to implement options of the *CREATE CAST* command. For more information about the *CREATE CAST* command, see the PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/current/static/sql-createcast.html
-
-The *Create - Cast* dialog organizes the development of a cast through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_cast_general.png
-
-Use the fields in the *General* tab to identify the cast:
-
-* The *Name* field is disabled. The name that will be displayed in the tree control is the *Source* type concatenated with the *Target* type, and is generated automatically when you make selections on the *Create - Cast* *Definition* tab. 
-* Store notes about the cast in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_cast_definition.png
-
-Use the fields in the *Definition* tab to define parameters:
-
-* Use the drop-down listbox next to *Source type* to select the name of the source data type of the cast.
-* Use the drop-down listbox next to *Target type* to select the name of the target data type of the cast.
-* Use the drop-down listbox next to *Function* to select the function used to perform the cast. The function's result data type must match the target type of the cast.
-* Slide the *Context* switch to the *Implicit* position if the cast is implicit. By default, a cast can be invoked only by an explicit cast request. If the cast is marked *Implicit* then it can be invoked implicitly in any context, whether assignment or internally in an expression.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_cast_sql.png
-
-Your entries in the *Create - Cast* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Cast* dialog:
-
-.. image:: images/create_cast_sql_example.png
-
diff --git a/docs/en_US/create_collation.rst b/docs/en_US/create_collation.rst
deleted file mode 100644
index b677b3f..0000000
--- a/docs/en_US/create_collation.rst
+++ /dev/null
@@ -1,59 +0,0 @@
-.. _create_collation:
-
-******************
-Create - Collation 
-******************
-
-
-Use the *Create - Collation* dialog to define a collation. To be able to create a collation, you must have a CREATE privilege on the destination schema.
-
-The *Create - Collation* dialog allows you to implement options of the CREATE COLLATION command. For more information about the CREATE COLLATION command, see the documentation available at:
-
-   http://www.postgresql.org/docs/current/static/sql-createcollation.html
-
-The *Create - Collation* dialog organizes the development of a collation through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_collation_general.png
-
-Use the fields in the *General* tab to identify the collation:
-
-* Use the *Name* field to add a name for the collation. The collation name must be unique within a schema. The name will be displayed in the *pgAdmin* tree control.
-* Select the name of the owner from the drop-down listbox in the *Owner* field.
-* Select the name of the schema in which the collation will reside from the drop-down listbox in the *Schema* field.
-* Store notes about the collation in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_collation_definition.png
-
-Use the fields in the *Definition* tab to specify operating system locale settings: 
-
-* Use the drop-down listbox next to *Copy collation* to select the name of an existing collation to copy. The new collation will have the same properties as the existing one, but will be an independent object. If you choose to copy an existing collation, you cannot modify the collation properties displayed on this tab.
-* Use the *Locale* field to specify a locale; a locale specifies language and language formatting characteristics. If you specify this, you cannot specify either of the following parameters. To view a list of locales supported by your Linux system use the command *locale -a*.
-* Use the *LC_COLLATE* field to specify a locale with specified string sort order. The locale must be applicable to the current database encoding. (See CREATE DATABASE for details.) 
-* Use the *LC_CTYPE* field to specify a locale with specified character classification. The locale must be applicable to the current database encoding. (See CREATE DATABASE for details.) 
-
-
-For more information about setting a locale, see Chapter 22.1 Locale Support of the PostgreSQL core documentation:
-   
-   http://www.postgresql.org/docs/9.5/static/locale.html
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_collation_sql.png
-
-Your entries in the *Create - Collation* dialog generate a generate a SQL command. The example shown demonstrates creating a collation named *french* that uses the rules specified for the locale, *fr_FR.utf8.  The collation is owned by *enterprisedb*.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Database* dialog: 
-
-.. image:: images/create_collation_sql_example.png
-
-
diff --git a/docs/en_US/create_database.rst b/docs/en_US/create_database.rst
deleted file mode 100644
index 8258a0e..0000000
--- a/docs/en_US/create_database.rst
+++ /dev/null
@@ -1,88 +0,0 @@
-.. _create_database:
-
-*****************
-Create - Database
-*****************
-
-Use the *Create - Database* dialog to create a database. To create a database, you must be a database superuser or have the CREATE privilege.  
-
-The *Create - Database* dialog allows you to implement options of the CREATE DATABASE command. For more information about the CREATE DATABASE command, please see:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createdatabase.html
-
- The *Create - Database* dialog organizes the development of a database through the following dialog tabs: *General*, *Definition*, *Security*, and *Parameters*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_database_general.png
-
-Use the fields in the *General* tab to identify the database:
-
-* Use the *Database* field to add a descriptive name for the database. The name will be displayed in the *pgAdmin* tree control.
-* Select the owner of the database from the drop-down listbox in the *Owner* field.
-* Store notes about the database in the *Comments* field.  
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_database_definition.png
-
-Use the *Definition* tab to set properties for the database:
-
-* Select a character set from the drop-down listbox in the *Encoding* field. The default is *UTF8*.
-* Select a template from the drop-down listbox in the *Template* field. 
-* Select a tablespace from the drop-down listbox in the *Tablespace* field. The selected tablespace will be the default tablespace used to contain database objects. 
-* Select the collation order from the drop-down listbox in the *Collation* field.
-* Select the character classification from the drop-down listbox in the *Character Type* field. This affects the categorization of characters, e.g. lower, upper and digit. The default, or a blank field, uses the character classification of the template database.
-* Specify a connection limit in the *Connection Limit* field to configure the maximum number of connection requests. The default value (*-1*) allows unlimited connections to the database.
- 
-Click the *Security* tab to continue.
-
-.. image:: images/create_database_security.png
-
-Use the *Security* tab to assign privileges and define security labels.  
-
-Use the *Privileges* panel to assign privileges to a role. Click *Add* to set privileges for database objects:
-
-* Select the name of the role from the drop-down listbox in the *Grantee* field.
-* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
-* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
-
-To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Use the *Security Labels* panel to define security labels applied to the database. Click *Add* to add each security label selection: 
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *Parameters* tab to continue.
-
-.. image:: images/create_database_parameters.png
-
-Use the *Parameters* tab to set parameters for the database:
-
-* Use the drop-down listbox next to *Parameter name* to select a parameter.
-* Use the drop-down listbox next to *Role* to select a role to which the parameter setting specified will apply.
-* Click *Add* to add the parameter definition to the table below.
-* Use the *Value* field to set a value for the parameter.
-
-Follow these steps to add additional parameter value definitions; to discard a parameter, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_database_sql.png
-
-Your entries in the *Create - Database* dialog generate a SQL command; you can review the command on the *SQL* pane. 
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Database* dialog: 
-
-.. image:: images/create_database_sql_example.png
-
-The example creates a database named *hr* that is owned by *enterprisedb*.  It allows unlimited connections, and is available to authenticated users in the *public* schema.  
diff --git a/docs/en_US/create_domain_constraint.rst b/docs/en_US/create_domain_constraint.rst
deleted file mode 100644
index 482f9eb..0000000
--- a/docs/en_US/create_domain_constraint.rst
+++ /dev/null
@@ -1,50 +0,0 @@
-.. _create_domain_constraint:
-
-**************************
-Create - Domain Constraint
-**************************
-
-Use the *Create - Domain Constraint* dialog to create a domain constraint. The *Create - Domain Constraint* dialog implements options of the ALTER DOMAIN command. For more information about the ALTER DOMAIN command, see PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/9.5/static/sql-alterdomain.html
-
-The *Create - Domain Constraint* dialog organizes the development of a domain constraint through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_domain_constraint_general.png
-   :align: center
-   
-Use the fields in the *General* tab to identify the domain constraint:
-* Use the *Name* field to add a descriptive name for the constraint. The name will be displayed in the *pgAdmin* tree control.
-* Store notes about the constraint in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_domain_constraint_definition.png
-   :align: center
-   
-Use the fields in the *Definition* tab to define the domain constraint:
-
-* Use the *Check* field to write a CHECK expression. A CHECK clause specifies a constraint that the domain must satisfy. A constraint must be an expression producing a Boolean result; include the key word VALUE to refer to the value being tested. Only those expressions that evaluate to TRUE or UNKNOWN succeed. A CHECK expressions cannot contain subqueries or refer to variables other than VALUE. When a domain has multiple CHECK constraints, they will be tested in alphabetical order by name.
-* Move the *Validate?* switch to the *No* position to mark the constraint NOT VALID. If the constraint is marked NOT VALID, the constraint will not be applied to existing column data. The default value is *Yes*. 
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_domain_constraint_sql.png
-   :align: center
-   
-Your entries in the *Create - Domain Constraint* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Domain Constraint* dialog: 
-
-.. image:: images/create_domain_constraint_sql_example.png
-
-The example shown demonstrates creating a domain constraint on the domain *timesheets* named *weekday*. It constrains a value to equal *Monday*, *Tuesday*, *Wednesday*, *Thursday*, or *Friday*.  
-
diff --git a/docs/en_US/create_event_trigger.rst b/docs/en_US/create_event_trigger.rst
deleted file mode 100644
index 9bfcbc7..0000000
--- a/docs/en_US/create_event_trigger.rst
+++ /dev/null
@@ -1,66 +0,0 @@
-.. _create_event trigger:
-
-*************************
-Create - Event Trigger
-*************************
- 
-Use the *Create - Event Trigger* dialog to define an event trigger. Unlike regular triggers, which are attached to a single table and capture only DML events, event triggers are global to a particular database and are capable of capturing DDL events.  Like regular triggers, event triggers can be written in any procedural language that includes event trigger support, or in C, but not in plain SQL.
-
-The *Create - Event Trigger* dialog allows you to implement options of the *CREATE EVENT TRIGGER* command. For more information about the *CREATE EVENT TRIGGER* command, see the PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createeventtrigger.html
-
-The *Create - Event Trigger* dialog organizes the development of a event trigger through the following dialog tabs: *General*, *Definition*, and *Security Labels*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_event_trigger_general.png
-
-Use the fields in the *General* tab to identify the event trigger:
-
-* Use the *Name* field to add a descriptive name for the event trigger. The name will be displayed in the *pgAdmin* tree control.
-* Use the drop-down listbox next to *Owner* to specify the owner of the event trigger. 
-* Store notes about the event trigger in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_event_trigger_definition.png
-
-Use the fields in the *Definition* tab to define the event trigger:
-
-* Select a radio button in the *Enabled Status* field to specify a status for the trigger: *Enable* *Disable*, *Replica* *Always*.
-* Use the drop-down listbox next to *Trigger function* to specify an existing function.  A trigger function takes an empty argument list, and returns a value of type event_trigger.
-* Select a radio button in the *Events* field to specify when the event trigger will fire: *DDL COMMAND START*, *DDL COMMAND END*, or *SQL DROP*.
-* Use the *When* field to write a condition for the event trigger that must be satisfied before the event trigger can execute.
-
-Click the *Security Labels* tab to continue. 
-
-.. image:: images/create_event_trigger_security.png
-
-Use the *Security* tab to define security labels applied to the trigger. Click *Add* to add each security label. 
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* dialog.
-
-For more information about using security Labels, please see the PostgreSQL Core documentation available at:
-
-   http://www.postgresql.org/docs/current/static/sql-security-label.html
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_event_trigger_sql.png
-
-Your entries in the *Create - Event Trigger* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Event Trigger* dialog: 
-
-.. image:: images/create_event_trigger_sql_example.png "FIXME"
-
diff --git a/docs/en_US/create_extension.rst b/docs/en_US/create_extension.rst
deleted file mode 100644
index b46ceaf..0000000
--- a/docs/en_US/create_extension.rst
+++ /dev/null
@@ -1,50 +0,0 @@
-.. _create_extension:
-
-*******************
-Create - Extension
-*******************
-
-Use the *Create - Extension* dialog to install a new extension into the current database. Each extension must have a unique name.  Before you can use CREATE EXTENSION to load an extension into a database, the extension's supporting files must be installed.
-
-The *Create - Extension* dialog allows you to implement options of the CREATE EXTENSION command through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-For more information about creating extensions, please see the PostgreSQL core documentation available at:
- 
-   http://www.postgresql.org/docs/9.5/static/sql-createextension.html
-   
-   http://www.postgresql.org/docs/current/static/extend-extensions.html
-
-.. image:: images/create_extension_general.png
-
-Use the fields in the *General* tab to identify an extension:
-
-* Use the drop-down listbox in the *Name* field to select the extension.   
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_extension_definition.png
-
-Use the *Definition* tab to select the *Schema* and *Version*:
-
-* Use the drop-down listbox next to *Schema* to select the name of the schema in which to install the extension's objects.  
-* Use the drop-down listbox next to *Version* to select the version of the extension to install. 
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_extension_sql.png
-
-Your entries in the *Create - Extension* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Extension* dialog: 
-
-.. image:: images/create_extension_sql_example.png
-
-The command creates the *adminpack* extension in the *pg_catalog* schema.  It is version *1.0* of *adminpack*.
\ No newline at end of file
diff --git a/docs/en_US/create_fdw.rst b/docs/en_US/create_fdw.rst
deleted file mode 100644
index 88bbd26..0000000
--- a/docs/en_US/create_fdw.rst
+++ /dev/null
@@ -1,75 +0,0 @@
-.. _create_fdw:
-
-*****************************
-Create - Foreign Data Wrapper
-*****************************
-
-Use the *Create - Foreign Data Wrapper* dialog to create a foreign data wrapper. The foreign data wrapper consists of a set of functions; all operations on a foreign table are handled through the foreign data wrapper. The foreign data wrapper is responsible for fetching data from the remote data source and returning it to the PostgreSQL executor. 
-
-A foreign-data wrapper name must be unique within the database.  You must be a superuser to create a foreign-data wrapper.
-
-The *Create - Foreign Data Wrapper* dialog allows you to implement options of the CREATE FOREIGN DATA WRAPPER command. For more information about the CREATE FOREIGN DATA WRAPPER command, see PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createforeigndatawrapper.html
-
-The *Create - Foreign Data Wrapper* dialog organizes the development of a foreign data wrapper through the following dialog tabs: *General*, *Definition*, *Options*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_fdw_general.png
-
-Use the fields in the *General* tab to identify the foreign data wrapper:
-
-* Use the *Name* field to add a descriptive name for the foreign data wrapper. The name will be displayed in the *Object browser* tree control.
-* Use the drop-down listbox next to *Owner* to select the name of the role that will own the foreign data wrapper.
-* Store notes about the foreign data wrapper in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_fdw_definition.png
-
-Use the fields in the *Definition* tab to set parameters:
-
-* Select the name of the handler from the drop-down listbox in the *Handler* field. This is the name of an existing function that will be called to retrieve the execution functions for foreign tables. 
-* Select the name of the validator from the drop-down listbox in the *Validator* field. This is the name of an existing function that will be called to check the generic options given to the foreign-data wrapper, as well as options for foreign servers, user mappings and foreign tables using the foreign-data wrapper.
-
-Click the *Options* tab to continue.
-
-.. image:: images/create_fdw_options.png
-
-Use the fields in the *Options* tab to specify options:
-
-* Click the *Add* button to add an option/value pair for the foreign data wrapper. Supported option/value pairs will be specific to the selected foreign data wrapper.
-* Specify the option name in the *Option* field and provide a corresponding value in the *Value* field.  
-
-Click *Add* to specify each additional pair; to discard an option, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *Security* tab to continue.
-
-.. image:: images/create_fdw_security.png
-
-Use the *Security* tab to assign security privileges. Click *Add* to assign a set of privileges.
-
-* Select the name of the role from the drop-down listbox in the *Grantee* field.
-* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privileges to the specified user.
-* Select the name of the role granting the privileges from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the foreign data wrapper.
-
-To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_fdw_sql.png
-
-Your entries in the *Create - Foreign Data Wrapper* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Help* button (?) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Foreign Data Wrapper* dialog: 
-
-.. image:: images/create_fdw_sql_example.png
-
-The example creates a foreign data wrapper named *libpq_debug* that uses pre-existing validator and handler functions, *dblink_fdw_validator* and *libpg_fdw_handler*.  Selections on the *Options* tab set *debug* equal to *true*.  The foreign data wrapper is owned by *enterprisedb*.
diff --git a/docs/en_US/create_fts_parser.rst b/docs/en_US/create_fts_parser.rst
deleted file mode 100644
index 04e3000..0000000
--- a/docs/en_US/create_fts_parser.rst
+++ /dev/null
@@ -1,44 +0,0 @@
-.. _fts_parser:
-
-*******************
-Create - FTS Parser     
-*******************
-
-Use the *Create - FTS Parser* dialog to create a new text search parser. A text search parser defines a method for splitting a text string into tokens and assigning types (categories) to the tokens. The *Create - FTS Parser* dialog allows you to implement options of the CREATE TEXT SEARCH PARSER command. For more information about the CREATE TEXT SEARCH PARSER command, see PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createtsparser.html
-
-The *Create - FTS Parser* dialog organizes the development of a text search parser through the following dialog tabs: *General*, and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
- 
-Click the *General* tab to begin.
-
-.. image:: images/create_fts_parser_general.png
-
-Use the fields in the *General* tab to identify a text search parser:
-
-* Use the *Name* field to add a descriptive name for the parser. The name will be displayed in the *pgAdmin* tree control.
-* Select the name of the schema in which the parser will reside from the drop-down listbox in the *Schema* field.
-* Store notes about the domain in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_fts_parser_definition.png
-
-Use the fields in the *Definition* tab to define parameters:
-
-* Use the drop-down listbox next to *Start function* to select the name of the start function for the parser.
-* Use the drop-down listbox next to *Get next token function* to select the name of the get-next-token function for the parser.
-* Use the drop-down listbox next to *End function* to select the name of the end function for the parser.
-* Use the drop-down listbox next to *Lextypes function* to select the name of the lextypes function for the parser (a function that returns information about the set of token types it produces).
-* Use the drop-down listbox next to *Headline function* to select the name of the headline function for the parser (a function that summarizes a set of tokens).
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_fts_parser_sql.png
-
-Your entries in the *Create - Extension* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
diff --git a/docs/en_US/create_fts_template.rst b/docs/en_US/create_fts_template.rst
deleted file mode 100644
index 39f2e61..0000000
--- a/docs/en_US/create_fts_template.rst
+++ /dev/null
@@ -1,52 +0,0 @@
-.. _fts_template:
-
-**********************
-Create - FTS Template     
-**********************
-
-Use the *Create - FTS Template* dialog to create a new text search template. A text search template defines the functions that implement text search dictionaries. The *Create - FTS Template* dialog allows you to implement options of the CREATE TEXT SEARCH TEMPLATE command. For more information about the CREATE TEXT SEARCH TEMPLATE command, see PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createtstemplate.html
-
-The *Create - FTS Template* dialog organizes the development of a text search Template through the following dialog tabs: *General*, and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_fts_template_general.png
-
-Use the fields in the *General* tab to identify a template:
-
-* Use the *Name* field to add a descriptive name for the template. The name will be displayed in the *pgAdmin* tree control.
-* Select the name of the schema in which the template will reside from the drop-down listbox in the *Schema* field.
-* Store notes about the domain in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_fts_template_definition.png
-
-Use the fields in the *Definition* tab to define function parameters:
-
-* Use the drop-down listbox next to *Init function* to select the name of the init function for the template. The init function is optional.
-* Use the drop-down listbox next to *Lexize function* to select the name of the lexize function for the template. The lexize function is required.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_fts_template_sql.png
-
-Your entries in the *Create - FTS Template* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - FTS Template* dialog: 
-
-.. image:: images/create_fts_template_sql_example.png
-
-The example shown demonstrates creating a fts template named *ru_template* that uses the ispell dictionary.
-
-
-
-
diff --git a/docs/en_US/create_function.rst b/docs/en_US/create_function.rst
deleted file mode 100644
index ac726ef..0000000
--- a/docs/en_US/create_function.rst
+++ /dev/null
@@ -1,116 +0,0 @@
-.. _create_function:
-
-*****************
-Create - Function
-*****************
-
-Use the *Create - Function* dialog to define a function.  If you drop and then recreate a function, the new function is not the same entity as the old; you must drop existing rules, views, triggers, etc. that refer to the old function. 
-
-The *Create - Function* dialog allows you to implement options of the CREATE FUNCTION and ALTER FUNCTION commands. For more information about the CREATE FUNCTION command, see the PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createfunction.html
-
-The *Create - Function* dialog organizes the development of a function through the following dialog tabs: *General*, *Definition*, *Options*, *Arguments*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_function_general.png
-
-Use the fields in the *General* tab to identify a function:
-
-* Use the *Name* field to add a descriptive name for the function. The name will be displayed in the *pgAdmin* tree control.
-* Use the drop-down listbox next to *Owner* to select the name of the role that will own the function.
-* Use the drop-down listbox next to *Schema* to select the schema in which the function will be created.
-* Store notes about the function in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_function_definition.png
-
-Use the fields in the *Definition* tab to define the function:
-
-* Use the drop-down listbox next to *Return type* to select the data type returned by the function, if any. 
-* Use the drop-down listbox next to *Language* to select the implementation language. 
-* Use the *Code* field to write the code that will execute when the function is called.
-
-Click the *Options* tab to continue.
-
-.. image:: images/create_function_options.png
-
-Use the fields in the *Options* tab to describe or modify the action of the function:
-
-* Use the drop-down listbox next to *Volatility* to select one of the following. *VOLATILE* is the default value.
-   *VOLATILE* indicates that the function value can change even within a single table scan, so no optimizations can be made. 
-   *STABLE* indicates that the function cannot modify the database, and that within a single table scan it will consistently return the same result for the same argument values.
-   *IMMUTABLE* indicates that the function cannot modify the database and always returns the same result when given the same argument values.
-* Use the *Returns a Set?* switch to indicate if the function returns a set that includes multiple rows. The default is *No*.
-* Use the *Strict?* switch to indicate if the function always returns NULL whenever any of its arguments are NULL. If *Yes*, the function is not executed when there are NULL arguments; instead a NULL result is assumed automatically. The default is *No*.
-* Use the *Security of definer?* switch to specify that the function is to be executed with the privileges of the user that created it. The default is *No*.
-* Use the *Window?* switch to indicate that the function is a window function rather than a plain function. The default is *No*. This is currently only useful for functions written in C. The WINDOW attribute cannot be changed when replacing an existing function definition. For more information about the CREATE FUNCTION command, see the PostgreSQL core documentation available at:
-   http://www.postgresql.org/docs/9.5/static/functions-window.html
-* Use the *Estimated cost* field to specify a positive number representing the estimated execution cost for the function, in units of cpu_operator_cost. If the function returns a set, this is the cost per returned row. 
-* Use the *Estimated rows* field to specify a positive number giving the estimated number of rows that the planner should expect the function to return. This is only allowed when the function is declared to return a set. The default assumption is 1000 rows.
-* Use the *Leak proof?* switch to indicate whether the function has side effects. The default is *No*. This option can only be set by the superuser.
-
-Click the *Arguments* tab to continue.
-
-.. image:: images/create_function_arguments.png
-
-Use the fields in the *Arguments* tab to define an argument. Click *Add* to set parameters and values for the argument:
-
-* Use the drop-down listbox next to *Data type* to select a data type.
-* Use the drop-down listbox next to *Mode* to select a mode. Select *IN* for an input parameter; select *OUT* for an output parameter; select *INOUT* for both an input and an output parameter; or, select *VARIADIC* to specify a VARIADIC parameter.
-* Write a name for the argument in the *Argument Name* field.
-* Specify a default value for the argument in the *Default Value* field.
-
-Click *Add* to define another argument; to discard an argument, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *Parameters* tab to continue.
-
-.. image:: images/create_function_parameters.png
-
-Use the fields in the *Parameters* tab to specify settings that will be applied when the function is invoked:
-
-* Use the drop-down listbox next to *Parameter Name* in the *Parameters* panel to select a parameter. 
-* Click the *Add* button to add the variable to *Name* field.
-* Use the *Value* field to specify the value that will be associated with the selected variable. This field is context-sensitive.
-
-Click the *Security* tab to continue.
-
-.. image:: images/create_function_security.png
-
-Use the *Security* tab to assign privileges and define security labels.  
-
-Use the *Privileges* panel to assign usage privileges for the function to a role. 
-
-* Select the name of the role from the drop-down listbox in the *Grantee* field.
-* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
-* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
-
-Click *Add* to assign additional privileges; to discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Use the *Security Labels* panel to define security labels applied to the function. Click *Add* to add each security label selection: 
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-Click *Add* to assign additional security labels; to discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_function_sql.png
-
-Your entries in the *Create - Function* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by selections made in the *Create - Function* dialog: 
-
-.. image:: images/create_function_sql_example.png
-
-The example demonstrates creating an *edbspl* function named *emp_comp*.  The function adds two columns (p_sal and p_comm), and then uses the result to compute a yearly salary, returning a NUMERIC value.
-
diff --git a/docs/en_US/create_procedure.rst b/docs/en_US/create_procedure.rst
deleted file mode 100644
index e8e1175..0000000
--- a/docs/en_US/create_procedure.rst
+++ /dev/null
@@ -1,109 +0,0 @@
-.. _create_procedure:
-
-******************
-Create - Procedure
-******************
- 
-Use the *Create - Procedure* dialog to create a procedure; procedures are supported by EDB Postgres Advanced Server. The *Create - Procedure* dialog allows you to implement options of the CREATE PROCEDURE command; for more information about the CREATE PROCEDURE SQL command, please see the Database Compatibility for Oracle Developer's, available at:
-
-     http://www.enterprisedb.com
-
-The *Create - Procedure* dialog organizes the development of a procedure through the following dialog tabs: *General*, *Definition*, *Options*, *Arguments*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
- 
-.. image:: images/create_procedure_general.png
-
-Use the fields in the *General* tab to identify a procedure:
-
-* Use the *Name* field to add a descriptive name for the procedure. The name will be displayed in the *pgAdmin* tree control.
-* Use the drop-down listbox next to *Owner* to select a role.
-* Select the name of the schema in which the procedure will reside from the drop-down listbox in the *Schema* field.
-* Store notes about the procedure in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_procedure_definition.png
-
-Use the fields in the *Definition* tab to define the procedure:
-
-* Use the drop-down listbox next to *Language* to select a language. The default is *edbspl*. 
-* Use the *Code* field to specify the code that will execute when the procedure is called.
-
-Click the *Options* tab to continue.
-
-.. image:: images/create_procedure_options.png
-
-Use the fields in the *Options* tab to describe or modify the behavior of the procedure:
-
-* Use the drop-down listbox under *Volatility* to select one of the following. *VOLATILE* is the default value.
-   *VOLATILE* indicates that the value can change even within a single table scan, so no optimizations can be made. 
-   *STABLE* indicates that the procedure cannot modify the database, and that within a single table scan it will consistently return the same result for the same argument values, but that its result could change across SQL statements. 
-   *IMMUTABLE* indicates that the procedure cannot modify the database and always returns the same result when given the same argument values.
-* Use the *Strict?* switch to indicate if the procedure always returns NULL whenever any of its arguments are NULL. If *Yes*, the procedure is not executed when there are NULL arguments; instead a NULL result is assumed automatically. The default is *No*.
-* Use the *Security of definer?* switch to specify that the procedure is to be executed with the privileges of the user that created it. The default is *No*.
-* Use the *Estimated cost* field to specify a positive number representing the estimated execution cost for the procedure, in units of cpu_operator_cost. If the procedure returns a set, this is the cost per returned row. 
-* Use the *Leak proof?* switch to indicate whether the procedure has side effects — it reveals no information about its arguments other than by its return value. The default is *No*. 
-
-Click the *Arguments* tab to continue.
-
-.. image:: images/create_procedure_arguments.png
-
-Use the fields in the *Arguments* tab to define an argument. Click *Add* to set parameters and values for the argument:
-
-* Use the drop-down listbox next to *Data type* to select a data type.
-* Use the drop-down listbox next to *Mode* to select a mode. Select *IN* for an input parameter; select *OUT* for an output parameter; select *INOUT* for both an input and an output parameter; or, select *VARIADIC* to specify a VARIADIC parameter.
-* Write a name for the argument in the *Argument Name* field.
-* Specify a default value for the argument in the *Default Value* field.
-
-Click *Add* to define another argument; to discard an argument, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *Parameters* tab to continue.
-
-.. image:: images/create_procedure_parameters.png
-
-Use the fields in the *Parameters* tab to specify settings that will be applied when the procedure is invoked:
-
-* Use the drop-down listbox next to *Parameter Name* in the *Parameters* panel to select a parameter. 
-* Click the *Add* button to add the variable to *Name* field.
-* Use the *Value* field to specify the value that will be associated with the selected variable. This field is context-sensitive.
-
-Click the *Security* tab to continue.
-
-.. image:: images/create_procedure_security.png
-
-Use the *Security* tab to assign privileges and define security labels.  
-
-Use the *Privileges* panel to assign execute privileges for the procedure to a role:  
-
-* Select the name of the role from the drop-down listbox in the *Grantee* field.
-* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
-* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
-
-Click *Add* to assign additional privileges; to discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Use the *Security Labels* panel to define security labels applied to the procedure. Click *Add* to add each security label selection: 
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-Click *Add* to assign additional security labels; to discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_procedure_sql.png
-
-Your entries in the *Create - Procedure* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by selections made in the *Create - Procedure* dialog: 
-
-.. image:: images/create_procedure_sql_example.png
-
-The example demonstrates creating a procedure that returns a list of employees from a table named *emp*.  The procedure is a SECURITY DEFINER, and will execute with the privileges of the role that defined the procedure.  
-
diff --git a/docs/en_US/create_resource_group.rst b/docs/en_US/create_resource_group.rst
deleted file mode 100644
index 9c97635..0000000
--- a/docs/en_US/create_resource_group.rst
+++ /dev/null
@@ -1,39 +0,0 @@
-.. _create_resource:
-
-***********************
-Create - Resource Group
-***********************
-
-Use the *Create - Resource Group* dialog to create a resource group and set values for the groups resources. A resource group is a named, global group on which various resource usage limits can be defined. The resource group is accessible from all databases in the cluster. To use the *Create - Resource Group* dialog, you must have superuser privileges.  Please note that resource groups are supported when connected to EDB Postgres Advanced Server; for more information about using resource groups, please see the EDB Postgres Advanced Server Guide, available at:
-
-   http://www.enterprisedb.com/
-
-The *Create - Resource Group* dialog organizes the development of a resource group through the *General* dialog tab. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_resource_group_general.png
-
-Use the fields in the *General* tab to specify resource group parameters:
-
-* Use the *Group Name* field to add a descriptive name for the resource group. This name will be displayed in the *pgAdmin* tree control.
-* Use the *CPU Rate Limit (%)* field to set the value of the CPU rate limit resource type assigned to the resource group. The valid range for a CPU rate limit is from 0 to 1.67772e+07. The default value is 0.
-* Use the *Dirty Rate Limit (KB)* field to set the value of the dirty rate limit resource type assigned to the resource group. The valid range for a dirty rate limit is from 0 to 1.67772e+07. The default value is 0.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_resource_group_sql.png
-
-Your entries in the *Create - Resource Group* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by selections made in the *Create - Resource Group* dialog: 
-
-.. image:: images/create_resource_group_sql_example.png
-
-The example creates a resource group named *acctg* that sets *cpu_rate_limit* to *2*, and *dirty_rate_limit* to *6144*.
\ No newline at end of file
diff --git a/docs/en_US/create_role.rst b/docs/en_US/create_role.rst
deleted file mode 100644
index e9c87a1..0000000
--- a/docs/en_US/create_role.rst
+++ /dev/null
@@ -1,96 +0,0 @@
-.. _create_role:
-
-*************************
-Create - Login/Group Role
-*************************
-
-A role may be an individual user (with or without login privileges) or a group of users. Note that roles defined at the cluster level are shared by all databases in the cluster. For more information about creating roles, please see the PostgreSQL core documentation available at:
- 
-   http://www.postgresql.org/docs/9.5/static/sql-createrole.html
-
-The dialog *Create - Login/Group Role* organizes the creation of roles through the following dialog tabs: *General*, *Definition*, *Role Privileges*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_role_general.png
-
-Use the fields in the *General* tab to identify the role.
-
-* Use the *Name* field to provide the name of the role. The name will be displayed in the *pgAdmin* tree control. 
-* Provide a note about the role in the *Comments* field. 
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_role_definition.png
-
-Use the *Definition* tab to set a password and configure connection rules:
-
-* Provide a password that will be associated with the role in the *Password* field. 
-* Provide an expiration date for the password in the *Account Expires* field (the role does not expire).  Provide the date in a mm/dd/yyyy format. The expiration date is not enforced when a user logs in with a non-password-based authentication method.
-* If the role is a login role, specify how many concurrent connections the role can make in the *Connection Limit* field. The default value (*-1*) allows unlimited connections.
-
-Click the *Role Privileges* tab to continue.
-
-.. image:: images/create_role_privileges.png
-
-Use the *Role Privileges* tab to grant privileges to the role.
-
-* Move the *Can login?* switch to the *Yes* position if the role has login privileges. The default value is *No*.  
-* Move the *Superuser* switch to the *Yes* position if the role is a superuser within the database. The default value is *No*.
-* Move the *Create roles?* switch to the *Yes* position to specify whether a role is permitted to create roles. A role with this privilege can alter and drop roles. The default value is *No*.
-* Move the *Create databases* switch to the *Yes* position to control whether a role can create databases. The default value is *No*.
-* The *Update catalogs?* switch is disabled until the role is given superuser privileges. Move the *Update catalogs?* switch to the *No* position to control whether a role can update catalogs. The default value is *Yes*.
-* Move the *Inherit rights from the parent roles?* switch to the *No* position if a role does not inherit privileges. The default value is *Yes*.
-* Move the *Can initiate streaming replication and backups?* switch to the *Yes* position to control whether a role can initiate streaming replication or put the system in and out of backup mode. The default value is *No*.
-* Specify members of the role in the *Role Membership* field by checking the checkbox to the right of the role name. Membership conveys the privileges granted to a role to each of its members. 
-
-Click the *Parameters* tab to continue.
-
-.. image:: images/create_role_parameters.png
-
-Use the fields on the *Parameters* tab to set session defaults for a selected configuration parameter when the user is connected to a specified database. This tab invokes the ALTER ROLE... SET configuration_parameter syntax.
-
-* Use the drop-down listbox next to *Parameter name* to select a parameter.
-* Use the drop-down listbox next to *Database* to select a database.
-
-Click *Add* after the above selections to create a parameter. Use the *Value* field to specify a value for the parameter.
-
-Click *Add* to specify each additional parameter; to discard a parameter, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *Security* tab to continue. 
-
-.. image:: images/create_role_security.png
-
-Use the *Security* tab to define security labels applied to the role. Click *Add* to add each security label selection. 
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-For more information about using security labels, please see the PostgreSQL Core documentation available at:
-
-   http://www.postgresql.org/docs/current/static/sql-security-label.html
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_role_sql.png
-
-Your entries in the *Create - Login/Group Role* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Login/Group Role* dialog: 
-
-.. image:: images/create_role_sql_example.png
-
-The example creates a login role named *alice*; the role is limited to 3 connections to the server at any given time.  When EDB auditing is enabled, any transactions written to the audit log by alice will include a tag that states *acctg - payroll*.
-
-
-
-
-
diff --git a/docs/en_US/create_schema.rst b/docs/en_US/create_schema.rst
deleted file mode 100644
index ccd6475..0000000
--- a/docs/en_US/create_schema.rst
+++ /dev/null
@@ -1,63 +0,0 @@
-.. _create_schema:
-
-***************
-Create - Schema  
-***************
-
-Use the *Create - Schema* dialog to define a schema. A schema is the organizational workhorse of a database, similar to directories or namespaces. To create a schema, you must be a database superuser or have the CREATE privilege.  
-
-The *Create - Schema* dialog allows you to implement options of the CREATE SCHEMA command. For more information about the CREATE SCHEMA command, please see:
-
-   http://www.postgresql.org/docs/current/static/sql-createschema.html
-
- The *Create - Schema* dialog organizes the development of schema through the following dialog tabs: *General* and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
- 
-.. image:: images/create_schema_general.png
-
-Use the fields on the *General* tab to identify the schema.
-
-* Use the *Name* field to add a descriptive name for the schema. 
-* Select the owner of the schema from the drop-down listbox in the *Owner* field.
-* Store notes about the schema in the *Comments* field.  
-
-Click the *Security* tab to continue.
-
-.. image:: images/create_schema_security.png
-
-Use the *Security* tab to assign privileges and security labels for the schema. 
-
-Click *Add* to assign a set of privileges in the *Privileges* panel:
-
-* Select the name of the role from the drop-down listbox in the *Grantee* field.
-* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privileges to the specified user.
-* Select the name of the role that is granting the privilege from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the schema.
-
-To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click *Add* to assign a security label in the *Security Labels* panel:
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_schema_sql.png
-
-Your entries in the *Create - Schema* dialog generate a SQL command; you can review the command on the *SQL* pane. 
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by selections made in the *Create - Schema* dialog: 
-
-.. image:: images/create_extension_sql_example.png
-
-The example creates a schema named hr; the command grants *USAGE* privileges to *public*.
- 
diff --git a/docs/en_US/create_sequence.rst b/docs/en_US/create_sequence.rst
deleted file mode 100644
index 5024d45..0000000
--- a/docs/en_US/create_sequence.rst
+++ /dev/null
@@ -1,85 +0,0 @@
-.. _create_sequence:
-
-*****************
-Create - Sequence
-*****************
-
-Use the *Create - Sequence* dialog to create a sequence.  A sequence generates unique values in a sequential order (not necessarily contiguous).  
-
-The *Create - Sequence* dialog allows you to implement options of the CREATE SEQUENCE command. For more information about the CREATE SEQUENCE command, see the PostgreSQL core documentation available at:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createsequence.html
-
-The *Create - Sequence* dialog organizes the development of a sequence through the following dialog tabs: *General*, *Definition*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_sequence_general.png
-   :align: center
-   
-Use the fields in the *General* tab to identify a sequence:
-
-* Use the *Name* field to add a descriptive name for the sequence. The name will be displayed in the *pgAdmin* tree control.  The sequence name must be distinct from the name of any other sequence, table, index, view, or foreign table in the same schema. 
-* Use the drop-down listbox next to *Owner* to select the name of the role that will own the extension.
-* Use the drop-down listbox next to *Schema* to select an existing schema.
-* Store notes about the sequence in the *Comments* field.
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_sequence_definition.png
-   :align: center
-   
-Use the fields in the *Definition* tab to define the sequence:
-
-* Use the *Increment* field to specify which value is added to the current sequence value to create a new value.
-* Provide a value in the *Start* field to specify the beginning value of the sequence. The default starting value is MINVALUE for ascending sequences and MAXVALUE for descending ones.
-* Provide a value in the *Minimum* field to specify the minimum value a sequence can generate. If this clause is not supplied or NO MINVALUE is specified, then defaults will be used. The defaults are 1 and -263-1 for ascending and descending sequences, respectively.
-* Provide a value in the *Maximum* field to specify the maximum value for the sequence. If this clause is not supplied or NO MAXVALUE is specified, then default values will be used. The defaults are 263-1 and -1 for ascending and descending sequences, respectively.
-* Provide a value in the *Cache* field to specify how many sequence numbers are to be preallocated and stored in memory for faster access. The minimum value is 1 (only one value can be generated at a time, i.e., no cache), and this is also the default.
-* Check the *Cycled* checkbox to allow the sequence to wrap around when the MAXVALUE or the MINVALUE has been reached by an ascending or descending sequence respectively. If the limit is reached, the next number generated will be the MINVALUE or MAXVALUE, respectively.
-
-Click the *Security* tab to continue.
-
-.. image:: images/create_sequence_security.png
-   :align: center
-
-Use the *Security* tab to assign privileges and define security labels.  
-
-Use the *Privileges* panel to assign privileges to a role. Click *Add* to set privileges for database objects:
-
-* Select the name of the role from the drop-down listbox in the *Grantee* field.
-* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
-* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
-
-
-Click *Add* to assign additional privileges; to discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Use the *Security Labels* panel to define security labels applied to the function. Click *Add* to add each security label selection: 
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-Click *Add* to assign additional security labels; to discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_sequence_sql.png
-   :align: center
-   
-Your entries in the *Create - Sequence* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Database* dialog: 
-
-.. image:: images/create_sequence_sql_example.png
-
-The example shown demonstrates a sequence named *seconds*. It will increment by *5*  with a start value equal to *0* (cached) and a maximum value equal to *60*.  
-
-
-
-
diff --git a/docs/en_US/create_server.rst b/docs/en_US/create_server.rst
deleted file mode 100644
index 07532fb..0000000
--- a/docs/en_US/create_server.rst
+++ /dev/null
@@ -1,34 +0,0 @@
-.. _create_server:
-
-***************
-Create - Server  
-***************
-
-Use the *Create - Server* dialog to describe a connection to a server. Note: you must ensure the pg_hba.conf file of the server from which you are connecting allows connections from the host of the client. 
-
-The *Create - Server* dialog organizes the connection of a server through the following dialog tabs: *General*, and *Connection*. 
-
-.. image:: images/create_server_general.png
-
-Use the fields in the *General* tab to identify the server:
-
-* Use the *Name* field to add a descriptive name for the server; the name specified will be displayed in the tree control of the client.
-* Provide a comment about the server in the *Comments* field.
-
-Click the *Connection* tab to continue.
-
-.. image:: images/create_server_connection.png
-
-Use the fields in the *Connection* tab to configure a connection:
-
-* Specify the IP address of the server host, or the fully qualified domain name in the *Host Name/Address* field. On Unix based systems, the address field may be left blank to use the default PostgreSQL Unix Domain Socket on the local machine, or may be set to an alternate path containing a PostgreSQL socket. If you enter a path, the path must begin with a "/".
-* Enter the listener port number of the server host in the *Port* field.
-* Use the *Maintenance Database* field to specify the name of the initial database to which the client will connect.  If you will be using pgAgent or adminpack objects, the :ref:`pgAgent <pgagent>` schema and :ref:`adminpack <extend>` objects should be installed on that database. 
-* Use the *User Name* field to specify the name of a role that will be used when authenticating with the server. 
-* Use the *Role* field to specify the name of a role that has privileges that will be conveyed to the client after authentication with the server. This selection allows you to connect as one role, and then assume the permissions of this specified role after the connection is established. Note that the connecting role must be a member of the role specified.
-* Use the drop-down list box in the SSL field to select the type of SSL connection the server should use. For more information about using SSL encryption, see Section 31.18 of the Postgres documentation:
-   
-   http://www.postgresql.org/docs/9.5/static/libpq-ssl.html
-
-
-  
diff --git a/docs/en_US/create_server_group.rst b/docs/en_US/create_server_group.rst
deleted file mode 100644
index b2c9a79..0000000
--- a/docs/en_US/create_server_group.rst
+++ /dev/null
@@ -1,19 +0,0 @@
-.. _create_server_group:
-
-*******************
-Create Server Group
-*******************
-
-Use the *Create - Server Group* dialog to add a new server group. Assign servers to server groups to simplify management of multiple servers. Server groups are displayed as part of the client tree control.  
-
-.. image:: images/create_server_group.png
-
-Use the *Name* field on the *Create - Server Group* dialog to specify a name that will identify the server group in the pgAdmin tree control.
-
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-To create server connections in a server group, right click on the named server group and select the *Create* option to open the *Create Server* dialog.  
-
diff --git a/docs/en_US/create_tablespace.rst b/docs/en_US/create_tablespace.rst
deleted file mode 100644
index 15456f3..0000000
--- a/docs/en_US/create_tablespace.rst
+++ /dev/null
@@ -1,77 +0,0 @@
-.. _create_tablespace:
-
-*******************
-Create - Tablespace
-*******************
-
-A tablespace allows superusers to define an alternative location on the file system where the data files containing database objects (such as tables and indexes) reside. Tablespaces are only supported on systems that support symbolic links. Note that a tablespace cannot be used independently of the cluster in which it is defined.
-
-The *Create - Tablespace* dialog allows you to implement options of the CREATE TABLESPACE command.  For more information about the CREATE TABLESPACE command, please see:
-
-   http://www.postgresql.org/docs/9.5/static/sql-createtablespace.html
-
-The *Create - Tablespace* dialog organizes the definition of a tablespace through the following tabs: *General*, *Definition*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
-
-.. image:: images/create_tablespace_general.png
-
-* Use the *Name* field to identify the tablespace with a descriptive name. The name cannot begin with pg\_; these names are reserved for system tablespaces. 
-* Select the owner of the tablespace from the drop-down listbox in the *Owner* field.
-* Store notes about the tablespace in the *Comments* field.  
-
-Click the *Definition* tab to continue.
-
-.. image:: images/create_tablespace_definition.png
-
-* Use the *Location* field to specify an absolute path to a directory that will contain the tablespace.
-
-Click the *Parameters* tab to continue.
-
-.. image:: images/create_tablespace_parameters.png
-
-Use the *Parameters* tab to set parameters for the tablespace:
-
-* Use the drop-down listbox next to *Parameter name* to select a parameter.
-* Click *Add* to add the parameter name to the table below.
-* Use the *Value* field to set a value for the parameter.
-
-Click *Add* to specify each additional parameter; to discard a parameter, click the trash icon to the left of the row and confirm deletion in the *Delete Row* dialog.
-
-Click the *Security* tab to continue.
-
-.. image:: images/create_tablespace_security.png
-
-Use the *Security* tab to assign privileges and define security labels. 
-
-Use the *Privileges* panel to assign security privileges to a role. Click *Add* to assign a set of privileges:
-
-* Select the name of the role from the drop-down listbox in the *Grantee* field.
-* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privileges to the specified user.
-* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the owner of the tablespace.
-
-To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Use the *Security Labels* panel to define security labels applied to the tablespace. Click *Add* to add each security label selection: 
-
-* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
-* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
-
-To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
-
-Click the *SQL* tab to continue.
-
-.. image:: images/create_tablespace_sql.png
-
-Your entries in the *Create - Tablespace* dialog generate a SQL command; you can review the command on the *SQL* pane.
- 
-* Click the *Info* button (i) to access online help. 
-* Click the *Save* button to save work.
-* Click the *Cancel* button to exit without saving work.
-* Click the *Reset* button to restore configuration parameters.
-
-Example
-=======
-
-The following is an example of the sql command generated by user selections in the *Create - Tablespace* dialog: 
-
-.. image:: images/create_tablespace_sql_example.png
-
diff --git a/docs/en_US/database.rst b/docs/en_US/database.rst
new file mode 100644
index 0000000..8258a0e
--- /dev/null
+++ b/docs/en_US/database.rst
@@ -0,0 +1,88 @@
+.. _create_database:
+
+*****************
+Create - Database
+*****************
+
+Use the *Create - Database* dialog to create a database. To create a database, you must be a database superuser or have the CREATE privilege.  
+
+The *Create - Database* dialog allows you to implement options of the CREATE DATABASE command. For more information about the CREATE DATABASE command, please see:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createdatabase.html
+
+ The *Create - Database* dialog organizes the development of a database through the following dialog tabs: *General*, *Definition*, *Security*, and *Parameters*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_database_general.png
+
+Use the fields in the *General* tab to identify the database:
+
+* Use the *Database* field to add a descriptive name for the database. The name will be displayed in the *pgAdmin* tree control.
+* Select the owner of the database from the drop-down listbox in the *Owner* field.
+* Store notes about the database in the *Comments* field.  
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_database_definition.png
+
+Use the *Definition* tab to set properties for the database:
+
+* Select a character set from the drop-down listbox in the *Encoding* field. The default is *UTF8*.
+* Select a template from the drop-down listbox in the *Template* field. 
+* Select a tablespace from the drop-down listbox in the *Tablespace* field. The selected tablespace will be the default tablespace used to contain database objects. 
+* Select the collation order from the drop-down listbox in the *Collation* field.
+* Select the character classification from the drop-down listbox in the *Character Type* field. This affects the categorization of characters, e.g. lower, upper and digit. The default, or a blank field, uses the character classification of the template database.
+* Specify a connection limit in the *Connection Limit* field to configure the maximum number of connection requests. The default value (*-1*) allows unlimited connections to the database.
+ 
+Click the *Security* tab to continue.
+
+.. image:: images/create_database_security.png
+
+Use the *Security* tab to assign privileges and define security labels.  
+
+Use the *Privileges* panel to assign privileges to a role. Click *Add* to set privileges for database objects:
+
+* Select the name of the role from the drop-down listbox in the *Grantee* field.
+* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
+* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
+
+To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Use the *Security Labels* panel to define security labels applied to the database. Click *Add* to add each security label selection: 
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *Parameters* tab to continue.
+
+.. image:: images/create_database_parameters.png
+
+Use the *Parameters* tab to set parameters for the database:
+
+* Use the drop-down listbox next to *Parameter name* to select a parameter.
+* Use the drop-down listbox next to *Role* to select a role to which the parameter setting specified will apply.
+* Click *Add* to add the parameter definition to the table below.
+* Use the *Value* field to set a value for the parameter.
+
+Follow these steps to add additional parameter value definitions; to discard a parameter, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_database_sql.png
+
+Your entries in the *Create - Database* dialog generate a SQL command; you can review the command on the *SQL* pane. 
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Database* dialog: 
+
+.. image:: images/create_database_sql_example.png
+
+The example creates a database named *hr* that is owned by *enterprisedb*.  It allows unlimited connections, and is available to authenticated users in the *public* schema.  
diff --git a/docs/en_US/domain_constraint.rst b/docs/en_US/domain_constraint.rst
new file mode 100644
index 0000000..482f9eb
--- /dev/null
+++ b/docs/en_US/domain_constraint.rst
@@ -0,0 +1,50 @@
+.. _create_domain_constraint:
+
+**************************
+Create - Domain Constraint
+**************************
+
+Use the *Create - Domain Constraint* dialog to create a domain constraint. The *Create - Domain Constraint* dialog implements options of the ALTER DOMAIN command. For more information about the ALTER DOMAIN command, see PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/9.5/static/sql-alterdomain.html
+
+The *Create - Domain Constraint* dialog organizes the development of a domain constraint through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_domain_constraint_general.png
+   :align: center
+   
+Use the fields in the *General* tab to identify the domain constraint:
+* Use the *Name* field to add a descriptive name for the constraint. The name will be displayed in the *pgAdmin* tree control.
+* Store notes about the constraint in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_domain_constraint_definition.png
+   :align: center
+   
+Use the fields in the *Definition* tab to define the domain constraint:
+
+* Use the *Check* field to write a CHECK expression. A CHECK clause specifies a constraint that the domain must satisfy. A constraint must be an expression producing a Boolean result; include the key word VALUE to refer to the value being tested. Only those expressions that evaluate to TRUE or UNKNOWN succeed. A CHECK expressions cannot contain subqueries or refer to variables other than VALUE. When a domain has multiple CHECK constraints, they will be tested in alphabetical order by name.
+* Move the *Validate?* switch to the *No* position to mark the constraint NOT VALID. If the constraint is marked NOT VALID, the constraint will not be applied to existing column data. The default value is *Yes*. 
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_domain_constraint_sql.png
+   :align: center
+   
+Your entries in the *Create - Domain Constraint* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Domain Constraint* dialog: 
+
+.. image:: images/create_domain_constraint_sql_example.png
+
+The example shown demonstrates creating a domain constraint on the domain *timesheets* named *weekday*. It constrains a value to equal *Monday*, *Tuesday*, *Wednesday*, *Thursday*, or *Friday*.  
+
diff --git a/docs/en_US/event_trigger.rst b/docs/en_US/event_trigger.rst
new file mode 100644
index 0000000..9bfcbc7
--- /dev/null
+++ b/docs/en_US/event_trigger.rst
@@ -0,0 +1,66 @@
+.. _create_event trigger:
+
+*************************
+Create - Event Trigger
+*************************
+ 
+Use the *Create - Event Trigger* dialog to define an event trigger. Unlike regular triggers, which are attached to a single table and capture only DML events, event triggers are global to a particular database and are capable of capturing DDL events.  Like regular triggers, event triggers can be written in any procedural language that includes event trigger support, or in C, but not in plain SQL.
+
+The *Create - Event Trigger* dialog allows you to implement options of the *CREATE EVENT TRIGGER* command. For more information about the *CREATE EVENT TRIGGER* command, see the PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createeventtrigger.html
+
+The *Create - Event Trigger* dialog organizes the development of a event trigger through the following dialog tabs: *General*, *Definition*, and *Security Labels*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_event_trigger_general.png
+
+Use the fields in the *General* tab to identify the event trigger:
+
+* Use the *Name* field to add a descriptive name for the event trigger. The name will be displayed in the *pgAdmin* tree control.
+* Use the drop-down listbox next to *Owner* to specify the owner of the event trigger. 
+* Store notes about the event trigger in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_event_trigger_definition.png
+
+Use the fields in the *Definition* tab to define the event trigger:
+
+* Select a radio button in the *Enabled Status* field to specify a status for the trigger: *Enable* *Disable*, *Replica* *Always*.
+* Use the drop-down listbox next to *Trigger function* to specify an existing function.  A trigger function takes an empty argument list, and returns a value of type event_trigger.
+* Select a radio button in the *Events* field to specify when the event trigger will fire: *DDL COMMAND START*, *DDL COMMAND END*, or *SQL DROP*.
+* Use the *When* field to write a condition for the event trigger that must be satisfied before the event trigger can execute.
+
+Click the *Security Labels* tab to continue. 
+
+.. image:: images/create_event_trigger_security.png
+
+Use the *Security* tab to define security labels applied to the trigger. Click *Add* to add each security label. 
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* dialog.
+
+For more information about using security Labels, please see the PostgreSQL Core documentation available at:
+
+   http://www.postgresql.org/docs/current/static/sql-security-label.html
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_event_trigger_sql.png
+
+Your entries in the *Create - Event Trigger* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Event Trigger* dialog: 
+
+.. image:: images/create_event_trigger_sql_example.png "FIXME"
+
diff --git a/docs/en_US/extension.rst b/docs/en_US/extension.rst
new file mode 100644
index 0000000..b46ceaf
--- /dev/null
+++ b/docs/en_US/extension.rst
@@ -0,0 +1,50 @@
+.. _create_extension:
+
+*******************
+Create - Extension
+*******************
+
+Use the *Create - Extension* dialog to install a new extension into the current database. Each extension must have a unique name.  Before you can use CREATE EXTENSION to load an extension into a database, the extension's supporting files must be installed.
+
+The *Create - Extension* dialog allows you to implement options of the CREATE EXTENSION command through the following dialog tabs: *General* and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+For more information about creating extensions, please see the PostgreSQL core documentation available at:
+ 
+   http://www.postgresql.org/docs/9.5/static/sql-createextension.html
+   
+   http://www.postgresql.org/docs/current/static/extend-extensions.html
+
+.. image:: images/create_extension_general.png
+
+Use the fields in the *General* tab to identify an extension:
+
+* Use the drop-down listbox in the *Name* field to select the extension.   
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_extension_definition.png
+
+Use the *Definition* tab to select the *Schema* and *Version*:
+
+* Use the drop-down listbox next to *Schema* to select the name of the schema in which to install the extension's objects.  
+* Use the drop-down listbox next to *Version* to select the version of the extension to install. 
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_extension_sql.png
+
+Your entries in the *Create - Extension* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Extension* dialog: 
+
+.. image:: images/create_extension_sql_example.png
+
+The command creates the *adminpack* extension in the *pg_catalog* schema.  It is version *1.0* of *adminpack*.
\ No newline at end of file
diff --git a/docs/en_US/fdw.rst b/docs/en_US/fdw.rst
new file mode 100644
index 0000000..88bbd26
--- /dev/null
+++ b/docs/en_US/fdw.rst
@@ -0,0 +1,75 @@
+.. _create_fdw:
+
+*****************************
+Create - Foreign Data Wrapper
+*****************************
+
+Use the *Create - Foreign Data Wrapper* dialog to create a foreign data wrapper. The foreign data wrapper consists of a set of functions; all operations on a foreign table are handled through the foreign data wrapper. The foreign data wrapper is responsible for fetching data from the remote data source and returning it to the PostgreSQL executor. 
+
+A foreign-data wrapper name must be unique within the database.  You must be a superuser to create a foreign-data wrapper.
+
+The *Create - Foreign Data Wrapper* dialog allows you to implement options of the CREATE FOREIGN DATA WRAPPER command. For more information about the CREATE FOREIGN DATA WRAPPER command, see PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createforeigndatawrapper.html
+
+The *Create - Foreign Data Wrapper* dialog organizes the development of a foreign data wrapper through the following dialog tabs: *General*, *Definition*, *Options*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_fdw_general.png
+
+Use the fields in the *General* tab to identify the foreign data wrapper:
+
+* Use the *Name* field to add a descriptive name for the foreign data wrapper. The name will be displayed in the *Object browser* tree control.
+* Use the drop-down listbox next to *Owner* to select the name of the role that will own the foreign data wrapper.
+* Store notes about the foreign data wrapper in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_fdw_definition.png
+
+Use the fields in the *Definition* tab to set parameters:
+
+* Select the name of the handler from the drop-down listbox in the *Handler* field. This is the name of an existing function that will be called to retrieve the execution functions for foreign tables. 
+* Select the name of the validator from the drop-down listbox in the *Validator* field. This is the name of an existing function that will be called to check the generic options given to the foreign-data wrapper, as well as options for foreign servers, user mappings and foreign tables using the foreign-data wrapper.
+
+Click the *Options* tab to continue.
+
+.. image:: images/create_fdw_options.png
+
+Use the fields in the *Options* tab to specify options:
+
+* Click the *Add* button to add an option/value pair for the foreign data wrapper. Supported option/value pairs will be specific to the selected foreign data wrapper.
+* Specify the option name in the *Option* field and provide a corresponding value in the *Value* field.  
+
+Click *Add* to specify each additional pair; to discard an option, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *Security* tab to continue.
+
+.. image:: images/create_fdw_security.png
+
+Use the *Security* tab to assign security privileges. Click *Add* to assign a set of privileges.
+
+* Select the name of the role from the drop-down listbox in the *Grantee* field.
+* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privileges to the specified user.
+* Select the name of the role granting the privileges from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the foreign data wrapper.
+
+To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_fdw_sql.png
+
+Your entries in the *Create - Foreign Data Wrapper* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Help* button (?) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Foreign Data Wrapper* dialog: 
+
+.. image:: images/create_fdw_sql_example.png
+
+The example creates a foreign data wrapper named *libpq_debug* that uses pre-existing validator and handler functions, *dblink_fdw_validator* and *libpg_fdw_handler*.  Selections on the *Options* tab set *debug* equal to *true*.  The foreign data wrapper is owned by *enterprisedb*.
diff --git a/docs/en_US/fts_parser.rst b/docs/en_US/fts_parser.rst
new file mode 100644
index 0000000..04e3000
--- /dev/null
+++ b/docs/en_US/fts_parser.rst
@@ -0,0 +1,44 @@
+.. _fts_parser:
+
+*******************
+Create - FTS Parser     
+*******************
+
+Use the *Create - FTS Parser* dialog to create a new text search parser. A text search parser defines a method for splitting a text string into tokens and assigning types (categories) to the tokens. The *Create - FTS Parser* dialog allows you to implement options of the CREATE TEXT SEARCH PARSER command. For more information about the CREATE TEXT SEARCH PARSER command, see PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createtsparser.html
+
+The *Create - FTS Parser* dialog organizes the development of a text search parser through the following dialog tabs: *General*, and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
+ 
+Click the *General* tab to begin.
+
+.. image:: images/create_fts_parser_general.png
+
+Use the fields in the *General* tab to identify a text search parser:
+
+* Use the *Name* field to add a descriptive name for the parser. The name will be displayed in the *pgAdmin* tree control.
+* Select the name of the schema in which the parser will reside from the drop-down listbox in the *Schema* field.
+* Store notes about the domain in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_fts_parser_definition.png
+
+Use the fields in the *Definition* tab to define parameters:
+
+* Use the drop-down listbox next to *Start function* to select the name of the start function for the parser.
+* Use the drop-down listbox next to *Get next token function* to select the name of the get-next-token function for the parser.
+* Use the drop-down listbox next to *End function* to select the name of the end function for the parser.
+* Use the drop-down listbox next to *Lextypes function* to select the name of the lextypes function for the parser (a function that returns information about the set of token types it produces).
+* Use the drop-down listbox next to *Headline function* to select the name of the headline function for the parser (a function that summarizes a set of tokens).
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_fts_parser_sql.png
+
+Your entries in the *Create - Extension* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
diff --git a/docs/en_US/fts_template.rst b/docs/en_US/fts_template.rst
new file mode 100644
index 0000000..39f2e61
--- /dev/null
+++ b/docs/en_US/fts_template.rst
@@ -0,0 +1,52 @@
+.. _fts_template:
+
+**********************
+Create - FTS Template     
+**********************
+
+Use the *Create - FTS Template* dialog to create a new text search template. A text search template defines the functions that implement text search dictionaries. The *Create - FTS Template* dialog allows you to implement options of the CREATE TEXT SEARCH TEMPLATE command. For more information about the CREATE TEXT SEARCH TEMPLATE command, see PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createtstemplate.html
+
+The *Create - FTS Template* dialog organizes the development of a text search Template through the following dialog tabs: *General*, and *Definition*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_fts_template_general.png
+
+Use the fields in the *General* tab to identify a template:
+
+* Use the *Name* field to add a descriptive name for the template. The name will be displayed in the *pgAdmin* tree control.
+* Select the name of the schema in which the template will reside from the drop-down listbox in the *Schema* field.
+* Store notes about the domain in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_fts_template_definition.png
+
+Use the fields in the *Definition* tab to define function parameters:
+
+* Use the drop-down listbox next to *Init function* to select the name of the init function for the template. The init function is optional.
+* Use the drop-down listbox next to *Lexize function* to select the name of the lexize function for the template. The lexize function is required.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_fts_template_sql.png
+
+Your entries in the *Create - FTS Template* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - FTS Template* dialog: 
+
+.. image:: images/create_fts_template_sql_example.png
+
+The example shown demonstrates creating a fts template named *ru_template* that uses the ispell dictionary.
+
+
+
+
diff --git a/docs/en_US/function.rst b/docs/en_US/function.rst
new file mode 100644
index 0000000..ac726ef
--- /dev/null
+++ b/docs/en_US/function.rst
@@ -0,0 +1,116 @@
+.. _create_function:
+
+*****************
+Create - Function
+*****************
+
+Use the *Create - Function* dialog to define a function.  If you drop and then recreate a function, the new function is not the same entity as the old; you must drop existing rules, views, triggers, etc. that refer to the old function. 
+
+The *Create - Function* dialog allows you to implement options of the CREATE FUNCTION and ALTER FUNCTION commands. For more information about the CREATE FUNCTION command, see the PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createfunction.html
+
+The *Create - Function* dialog organizes the development of a function through the following dialog tabs: *General*, *Definition*, *Options*, *Arguments*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_function_general.png
+
+Use the fields in the *General* tab to identify a function:
+
+* Use the *Name* field to add a descriptive name for the function. The name will be displayed in the *pgAdmin* tree control.
+* Use the drop-down listbox next to *Owner* to select the name of the role that will own the function.
+* Use the drop-down listbox next to *Schema* to select the schema in which the function will be created.
+* Store notes about the function in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_function_definition.png
+
+Use the fields in the *Definition* tab to define the function:
+
+* Use the drop-down listbox next to *Return type* to select the data type returned by the function, if any. 
+* Use the drop-down listbox next to *Language* to select the implementation language. 
+* Use the *Code* field to write the code that will execute when the function is called.
+
+Click the *Options* tab to continue.
+
+.. image:: images/create_function_options.png
+
+Use the fields in the *Options* tab to describe or modify the action of the function:
+
+* Use the drop-down listbox next to *Volatility* to select one of the following. *VOLATILE* is the default value.
+   *VOLATILE* indicates that the function value can change even within a single table scan, so no optimizations can be made. 
+   *STABLE* indicates that the function cannot modify the database, and that within a single table scan it will consistently return the same result for the same argument values.
+   *IMMUTABLE* indicates that the function cannot modify the database and always returns the same result when given the same argument values.
+* Use the *Returns a Set?* switch to indicate if the function returns a set that includes multiple rows. The default is *No*.
+* Use the *Strict?* switch to indicate if the function always returns NULL whenever any of its arguments are NULL. If *Yes*, the function is not executed when there are NULL arguments; instead a NULL result is assumed automatically. The default is *No*.
+* Use the *Security of definer?* switch to specify that the function is to be executed with the privileges of the user that created it. The default is *No*.
+* Use the *Window?* switch to indicate that the function is a window function rather than a plain function. The default is *No*. This is currently only useful for functions written in C. The WINDOW attribute cannot be changed when replacing an existing function definition. For more information about the CREATE FUNCTION command, see the PostgreSQL core documentation available at:
+   http://www.postgresql.org/docs/9.5/static/functions-window.html
+* Use the *Estimated cost* field to specify a positive number representing the estimated execution cost for the function, in units of cpu_operator_cost. If the function returns a set, this is the cost per returned row. 
+* Use the *Estimated rows* field to specify a positive number giving the estimated number of rows that the planner should expect the function to return. This is only allowed when the function is declared to return a set. The default assumption is 1000 rows.
+* Use the *Leak proof?* switch to indicate whether the function has side effects. The default is *No*. This option can only be set by the superuser.
+
+Click the *Arguments* tab to continue.
+
+.. image:: images/create_function_arguments.png
+
+Use the fields in the *Arguments* tab to define an argument. Click *Add* to set parameters and values for the argument:
+
+* Use the drop-down listbox next to *Data type* to select a data type.
+* Use the drop-down listbox next to *Mode* to select a mode. Select *IN* for an input parameter; select *OUT* for an output parameter; select *INOUT* for both an input and an output parameter; or, select *VARIADIC* to specify a VARIADIC parameter.
+* Write a name for the argument in the *Argument Name* field.
+* Specify a default value for the argument in the *Default Value* field.
+
+Click *Add* to define another argument; to discard an argument, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *Parameters* tab to continue.
+
+.. image:: images/create_function_parameters.png
+
+Use the fields in the *Parameters* tab to specify settings that will be applied when the function is invoked:
+
+* Use the drop-down listbox next to *Parameter Name* in the *Parameters* panel to select a parameter. 
+* Click the *Add* button to add the variable to *Name* field.
+* Use the *Value* field to specify the value that will be associated with the selected variable. This field is context-sensitive.
+
+Click the *Security* tab to continue.
+
+.. image:: images/create_function_security.png
+
+Use the *Security* tab to assign privileges and define security labels.  
+
+Use the *Privileges* panel to assign usage privileges for the function to a role. 
+
+* Select the name of the role from the drop-down listbox in the *Grantee* field.
+* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
+* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
+
+Click *Add* to assign additional privileges; to discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Use the *Security Labels* panel to define security labels applied to the function. Click *Add* to add each security label selection: 
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+Click *Add* to assign additional security labels; to discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_function_sql.png
+
+Your entries in the *Create - Function* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by selections made in the *Create - Function* dialog: 
+
+.. image:: images/create_function_sql_example.png
+
+The example demonstrates creating an *edbspl* function named *emp_comp*.  The function adds two columns (p_sal and p_comm), and then uses the result to compute a yearly salary, returning a NUMERIC value.
+
diff --git a/docs/en_US/procedure.rst b/docs/en_US/procedure.rst
new file mode 100644
index 0000000..e8e1175
--- /dev/null
+++ b/docs/en_US/procedure.rst
@@ -0,0 +1,109 @@
+.. _create_procedure:
+
+******************
+Create - Procedure
+******************
+ 
+Use the *Create - Procedure* dialog to create a procedure; procedures are supported by EDB Postgres Advanced Server. The *Create - Procedure* dialog allows you to implement options of the CREATE PROCEDURE command; for more information about the CREATE PROCEDURE SQL command, please see the Database Compatibility for Oracle Developer's, available at:
+
+     http://www.enterprisedb.com
+
+The *Create - Procedure* dialog organizes the development of a procedure through the following dialog tabs: *General*, *Definition*, *Options*, *Arguments*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
+ 
+.. image:: images/create_procedure_general.png
+
+Use the fields in the *General* tab to identify a procedure:
+
+* Use the *Name* field to add a descriptive name for the procedure. The name will be displayed in the *pgAdmin* tree control.
+* Use the drop-down listbox next to *Owner* to select a role.
+* Select the name of the schema in which the procedure will reside from the drop-down listbox in the *Schema* field.
+* Store notes about the procedure in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_procedure_definition.png
+
+Use the fields in the *Definition* tab to define the procedure:
+
+* Use the drop-down listbox next to *Language* to select a language. The default is *edbspl*. 
+* Use the *Code* field to specify the code that will execute when the procedure is called.
+
+Click the *Options* tab to continue.
+
+.. image:: images/create_procedure_options.png
+
+Use the fields in the *Options* tab to describe or modify the behavior of the procedure:
+
+* Use the drop-down listbox under *Volatility* to select one of the following. *VOLATILE* is the default value.
+   *VOLATILE* indicates that the value can change even within a single table scan, so no optimizations can be made. 
+   *STABLE* indicates that the procedure cannot modify the database, and that within a single table scan it will consistently return the same result for the same argument values, but that its result could change across SQL statements. 
+   *IMMUTABLE* indicates that the procedure cannot modify the database and always returns the same result when given the same argument values.
+* Use the *Strict?* switch to indicate if the procedure always returns NULL whenever any of its arguments are NULL. If *Yes*, the procedure is not executed when there are NULL arguments; instead a NULL result is assumed automatically. The default is *No*.
+* Use the *Security of definer?* switch to specify that the procedure is to be executed with the privileges of the user that created it. The default is *No*.
+* Use the *Estimated cost* field to specify a positive number representing the estimated execution cost for the procedure, in units of cpu_operator_cost. If the procedure returns a set, this is the cost per returned row. 
+* Use the *Leak proof?* switch to indicate whether the procedure has side effects — it reveals no information about its arguments other than by its return value. The default is *No*. 
+
+Click the *Arguments* tab to continue.
+
+.. image:: images/create_procedure_arguments.png
+
+Use the fields in the *Arguments* tab to define an argument. Click *Add* to set parameters and values for the argument:
+
+* Use the drop-down listbox next to *Data type* to select a data type.
+* Use the drop-down listbox next to *Mode* to select a mode. Select *IN* for an input parameter; select *OUT* for an output parameter; select *INOUT* for both an input and an output parameter; or, select *VARIADIC* to specify a VARIADIC parameter.
+* Write a name for the argument in the *Argument Name* field.
+* Specify a default value for the argument in the *Default Value* field.
+
+Click *Add* to define another argument; to discard an argument, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *Parameters* tab to continue.
+
+.. image:: images/create_procedure_parameters.png
+
+Use the fields in the *Parameters* tab to specify settings that will be applied when the procedure is invoked:
+
+* Use the drop-down listbox next to *Parameter Name* in the *Parameters* panel to select a parameter. 
+* Click the *Add* button to add the variable to *Name* field.
+* Use the *Value* field to specify the value that will be associated with the selected variable. This field is context-sensitive.
+
+Click the *Security* tab to continue.
+
+.. image:: images/create_procedure_security.png
+
+Use the *Security* tab to assign privileges and define security labels.  
+
+Use the *Privileges* panel to assign execute privileges for the procedure to a role:  
+
+* Select the name of the role from the drop-down listbox in the *Grantee* field.
+* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
+* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
+
+Click *Add* to assign additional privileges; to discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Use the *Security Labels* panel to define security labels applied to the procedure. Click *Add* to add each security label selection: 
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+Click *Add* to assign additional security labels; to discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_procedure_sql.png
+
+Your entries in the *Create - Procedure* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by selections made in the *Create - Procedure* dialog: 
+
+.. image:: images/create_procedure_sql_example.png
+
+The example demonstrates creating a procedure that returns a list of employees from a table named *emp*.  The procedure is a SECURITY DEFINER, and will execute with the privileges of the role that defined the procedure.  
+
diff --git a/docs/en_US/resource_group.rst b/docs/en_US/resource_group.rst
new file mode 100644
index 0000000..9c97635
--- /dev/null
+++ b/docs/en_US/resource_group.rst
@@ -0,0 +1,39 @@
+.. _create_resource:
+
+***********************
+Create - Resource Group
+***********************
+
+Use the *Create - Resource Group* dialog to create a resource group and set values for the groups resources. A resource group is a named, global group on which various resource usage limits can be defined. The resource group is accessible from all databases in the cluster. To use the *Create - Resource Group* dialog, you must have superuser privileges.  Please note that resource groups are supported when connected to EDB Postgres Advanced Server; for more information about using resource groups, please see the EDB Postgres Advanced Server Guide, available at:
+
+   http://www.enterprisedb.com/
+
+The *Create - Resource Group* dialog organizes the development of a resource group through the *General* dialog tab. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_resource_group_general.png
+
+Use the fields in the *General* tab to specify resource group parameters:
+
+* Use the *Group Name* field to add a descriptive name for the resource group. This name will be displayed in the *pgAdmin* tree control.
+* Use the *CPU Rate Limit (%)* field to set the value of the CPU rate limit resource type assigned to the resource group. The valid range for a CPU rate limit is from 0 to 1.67772e+07. The default value is 0.
+* Use the *Dirty Rate Limit (KB)* field to set the value of the dirty rate limit resource type assigned to the resource group. The valid range for a dirty rate limit is from 0 to 1.67772e+07. The default value is 0.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_resource_group_sql.png
+
+Your entries in the *Create - Resource Group* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by selections made in the *Create - Resource Group* dialog: 
+
+.. image:: images/create_resource_group_sql_example.png
+
+The example creates a resource group named *acctg* that sets *cpu_rate_limit* to *2*, and *dirty_rate_limit* to *6144*.
\ No newline at end of file
diff --git a/docs/en_US/role.rst b/docs/en_US/role.rst
new file mode 100644
index 0000000..e9c87a1
--- /dev/null
+++ b/docs/en_US/role.rst
@@ -0,0 +1,96 @@
+.. _create_role:
+
+*************************
+Create - Login/Group Role
+*************************
+
+A role may be an individual user (with or without login privileges) or a group of users. Note that roles defined at the cluster level are shared by all databases in the cluster. For more information about creating roles, please see the PostgreSQL core documentation available at:
+ 
+   http://www.postgresql.org/docs/9.5/static/sql-createrole.html
+
+The dialog *Create - Login/Group Role* organizes the creation of roles through the following dialog tabs: *General*, *Definition*, *Role Privileges*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_role_general.png
+
+Use the fields in the *General* tab to identify the role.
+
+* Use the *Name* field to provide the name of the role. The name will be displayed in the *pgAdmin* tree control. 
+* Provide a note about the role in the *Comments* field. 
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_role_definition.png
+
+Use the *Definition* tab to set a password and configure connection rules:
+
+* Provide a password that will be associated with the role in the *Password* field. 
+* Provide an expiration date for the password in the *Account Expires* field (the role does not expire).  Provide the date in a mm/dd/yyyy format. The expiration date is not enforced when a user logs in with a non-password-based authentication method.
+* If the role is a login role, specify how many concurrent connections the role can make in the *Connection Limit* field. The default value (*-1*) allows unlimited connections.
+
+Click the *Role Privileges* tab to continue.
+
+.. image:: images/create_role_privileges.png
+
+Use the *Role Privileges* tab to grant privileges to the role.
+
+* Move the *Can login?* switch to the *Yes* position if the role has login privileges. The default value is *No*.  
+* Move the *Superuser* switch to the *Yes* position if the role is a superuser within the database. The default value is *No*.
+* Move the *Create roles?* switch to the *Yes* position to specify whether a role is permitted to create roles. A role with this privilege can alter and drop roles. The default value is *No*.
+* Move the *Create databases* switch to the *Yes* position to control whether a role can create databases. The default value is *No*.
+* The *Update catalogs?* switch is disabled until the role is given superuser privileges. Move the *Update catalogs?* switch to the *No* position to control whether a role can update catalogs. The default value is *Yes*.
+* Move the *Inherit rights from the parent roles?* switch to the *No* position if a role does not inherit privileges. The default value is *Yes*.
+* Move the *Can initiate streaming replication and backups?* switch to the *Yes* position to control whether a role can initiate streaming replication or put the system in and out of backup mode. The default value is *No*.
+* Specify members of the role in the *Role Membership* field by checking the checkbox to the right of the role name. Membership conveys the privileges granted to a role to each of its members. 
+
+Click the *Parameters* tab to continue.
+
+.. image:: images/create_role_parameters.png
+
+Use the fields on the *Parameters* tab to set session defaults for a selected configuration parameter when the user is connected to a specified database. This tab invokes the ALTER ROLE... SET configuration_parameter syntax.
+
+* Use the drop-down listbox next to *Parameter name* to select a parameter.
+* Use the drop-down listbox next to *Database* to select a database.
+
+Click *Add* after the above selections to create a parameter. Use the *Value* field to specify a value for the parameter.
+
+Click *Add* to specify each additional parameter; to discard a parameter, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *Security* tab to continue. 
+
+.. image:: images/create_role_security.png
+
+Use the *Security* tab to define security labels applied to the role. Click *Add* to add each security label selection. 
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+For more information about using security labels, please see the PostgreSQL Core documentation available at:
+
+   http://www.postgresql.org/docs/current/static/sql-security-label.html
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_role_sql.png
+
+Your entries in the *Create - Login/Group Role* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Login/Group Role* dialog: 
+
+.. image:: images/create_role_sql_example.png
+
+The example creates a login role named *alice*; the role is limited to 3 connections to the server at any given time.  When EDB auditing is enabled, any transactions written to the audit log by alice will include a tag that states *acctg - payroll*.
+
+
+
+
+
diff --git a/docs/en_US/schema.rst b/docs/en_US/schema.rst
new file mode 100644
index 0000000..ccd6475
--- /dev/null
+++ b/docs/en_US/schema.rst
@@ -0,0 +1,63 @@
+.. _create_schema:
+
+***************
+Create - Schema  
+***************
+
+Use the *Create - Schema* dialog to define a schema. A schema is the organizational workhorse of a database, similar to directories or namespaces. To create a schema, you must be a database superuser or have the CREATE privilege.  
+
+The *Create - Schema* dialog allows you to implement options of the CREATE SCHEMA command. For more information about the CREATE SCHEMA command, please see:
+
+   http://www.postgresql.org/docs/current/static/sql-createschema.html
+
+ The *Create - Schema* dialog organizes the development of schema through the following dialog tabs: *General* and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
+ 
+.. image:: images/create_schema_general.png
+
+Use the fields on the *General* tab to identify the schema.
+
+* Use the *Name* field to add a descriptive name for the schema. 
+* Select the owner of the schema from the drop-down listbox in the *Owner* field.
+* Store notes about the schema in the *Comments* field.  
+
+Click the *Security* tab to continue.
+
+.. image:: images/create_schema_security.png
+
+Use the *Security* tab to assign privileges and security labels for the schema. 
+
+Click *Add* to assign a set of privileges in the *Privileges* panel:
+
+* Select the name of the role from the drop-down listbox in the *Grantee* field.
+* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privileges to the specified user.
+* Select the name of the role that is granting the privilege from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the schema.
+
+To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click *Add* to assign a security label in the *Security Labels* panel:
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_schema_sql.png
+
+Your entries in the *Create - Schema* dialog generate a SQL command; you can review the command on the *SQL* pane. 
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by selections made in the *Create - Schema* dialog: 
+
+.. image:: images/create_extension_sql_example.png
+
+The example creates a schema named hr; the command grants *USAGE* privileges to *public*.
+ 
diff --git a/docs/en_US/sequence.rst b/docs/en_US/sequence.rst
new file mode 100644
index 0000000..5024d45
--- /dev/null
+++ b/docs/en_US/sequence.rst
@@ -0,0 +1,85 @@
+.. _create_sequence:
+
+*****************
+Create - Sequence
+*****************
+
+Use the *Create - Sequence* dialog to create a sequence.  A sequence generates unique values in a sequential order (not necessarily contiguous).  
+
+The *Create - Sequence* dialog allows you to implement options of the CREATE SEQUENCE command. For more information about the CREATE SEQUENCE command, see the PostgreSQL core documentation available at:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createsequence.html
+
+The *Create - Sequence* dialog organizes the development of a sequence through the following dialog tabs: *General*, *Definition*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_sequence_general.png
+   :align: center
+   
+Use the fields in the *General* tab to identify a sequence:
+
+* Use the *Name* field to add a descriptive name for the sequence. The name will be displayed in the *pgAdmin* tree control.  The sequence name must be distinct from the name of any other sequence, table, index, view, or foreign table in the same schema. 
+* Use the drop-down listbox next to *Owner* to select the name of the role that will own the extension.
+* Use the drop-down listbox next to *Schema* to select an existing schema.
+* Store notes about the sequence in the *Comments* field.
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_sequence_definition.png
+   :align: center
+   
+Use the fields in the *Definition* tab to define the sequence:
+
+* Use the *Increment* field to specify which value is added to the current sequence value to create a new value.
+* Provide a value in the *Start* field to specify the beginning value of the sequence. The default starting value is MINVALUE for ascending sequences and MAXVALUE for descending ones.
+* Provide a value in the *Minimum* field to specify the minimum value a sequence can generate. If this clause is not supplied or NO MINVALUE is specified, then defaults will be used. The defaults are 1 and -263-1 for ascending and descending sequences, respectively.
+* Provide a value in the *Maximum* field to specify the maximum value for the sequence. If this clause is not supplied or NO MAXVALUE is specified, then default values will be used. The defaults are 263-1 and -1 for ascending and descending sequences, respectively.
+* Provide a value in the *Cache* field to specify how many sequence numbers are to be preallocated and stored in memory for faster access. The minimum value is 1 (only one value can be generated at a time, i.e., no cache), and this is also the default.
+* Check the *Cycled* checkbox to allow the sequence to wrap around when the MAXVALUE or the MINVALUE has been reached by an ascending or descending sequence respectively. If the limit is reached, the next number generated will be the MINVALUE or MAXVALUE, respectively.
+
+Click the *Security* tab to continue.
+
+.. image:: images/create_sequence_security.png
+   :align: center
+
+Use the *Security* tab to assign privileges and define security labels.  
+
+Use the *Privileges* panel to assign privileges to a role. Click *Add* to set privileges for database objects:
+
+* Select the name of the role from the drop-down listbox in the *Grantee* field.
+* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privilege to the specified user.
+* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the database.
+
+
+Click *Add* to assign additional privileges; to discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Use the *Security Labels* panel to define security labels applied to the function. Click *Add* to add each security label selection: 
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+Click *Add* to assign additional security labels; to discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_sequence_sql.png
+   :align: center
+   
+Your entries in the *Create - Sequence* dialog generate a generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Database* dialog: 
+
+.. image:: images/create_sequence_sql_example.png
+
+The example shown demonstrates a sequence named *seconds*. It will increment by *5*  with a start value equal to *0* (cached) and a maximum value equal to *60*.  
+
+
+
+
diff --git a/docs/en_US/server.rst b/docs/en_US/server.rst
new file mode 100644
index 0000000..07532fb
--- /dev/null
+++ b/docs/en_US/server.rst
@@ -0,0 +1,34 @@
+.. _create_server:
+
+***************
+Create - Server  
+***************
+
+Use the *Create - Server* dialog to describe a connection to a server. Note: you must ensure the pg_hba.conf file of the server from which you are connecting allows connections from the host of the client. 
+
+The *Create - Server* dialog organizes the connection of a server through the following dialog tabs: *General*, and *Connection*. 
+
+.. image:: images/create_server_general.png
+
+Use the fields in the *General* tab to identify the server:
+
+* Use the *Name* field to add a descriptive name for the server; the name specified will be displayed in the tree control of the client.
+* Provide a comment about the server in the *Comments* field.
+
+Click the *Connection* tab to continue.
+
+.. image:: images/create_server_connection.png
+
+Use the fields in the *Connection* tab to configure a connection:
+
+* Specify the IP address of the server host, or the fully qualified domain name in the *Host Name/Address* field. On Unix based systems, the address field may be left blank to use the default PostgreSQL Unix Domain Socket on the local machine, or may be set to an alternate path containing a PostgreSQL socket. If you enter a path, the path must begin with a "/".
+* Enter the listener port number of the server host in the *Port* field.
+* Use the *Maintenance Database* field to specify the name of the initial database to which the client will connect.  If you will be using pgAgent or adminpack objects, the :ref:`pgAgent <pgagent>` schema and :ref:`adminpack <extend>` objects should be installed on that database. 
+* Use the *User Name* field to specify the name of a role that will be used when authenticating with the server. 
+* Use the *Role* field to specify the name of a role that has privileges that will be conveyed to the client after authentication with the server. This selection allows you to connect as one role, and then assume the permissions of this specified role after the connection is established. Note that the connecting role must be a member of the role specified.
+* Use the drop-down list box in the SSL field to select the type of SSL connection the server should use. For more information about using SSL encryption, see Section 31.18 of the Postgres documentation:
+   
+   http://www.postgresql.org/docs/9.5/static/libpq-ssl.html
+
+
+  
diff --git a/docs/en_US/server_group.rst b/docs/en_US/server_group.rst
new file mode 100644
index 0000000..b2c9a79
--- /dev/null
+++ b/docs/en_US/server_group.rst
@@ -0,0 +1,19 @@
+.. _create_server_group:
+
+*******************
+Create Server Group
+*******************
+
+Use the *Create - Server Group* dialog to add a new server group. Assign servers to server groups to simplify management of multiple servers. Server groups are displayed as part of the client tree control.  
+
+.. image:: images/create_server_group.png
+
+Use the *Name* field on the *Create - Server Group* dialog to specify a name that will identify the server group in the pgAdmin tree control.
+
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+To create server connections in a server group, right click on the named server group and select the *Create* option to open the *Create Server* dialog.  
+
diff --git a/docs/en_US/tablespace.rst b/docs/en_US/tablespace.rst
new file mode 100644
index 0000000..15456f3
--- /dev/null
+++ b/docs/en_US/tablespace.rst
@@ -0,0 +1,77 @@
+.. _create_tablespace:
+
+*******************
+Create - Tablespace
+*******************
+
+A tablespace allows superusers to define an alternative location on the file system where the data files containing database objects (such as tables and indexes) reside. Tablespaces are only supported on systems that support symbolic links. Note that a tablespace cannot be used independently of the cluster in which it is defined.
+
+The *Create - Tablespace* dialog allows you to implement options of the CREATE TABLESPACE command.  For more information about the CREATE TABLESPACE command, please see:
+
+   http://www.postgresql.org/docs/9.5/static/sql-createtablespace.html
+
+The *Create - Tablespace* dialog organizes the definition of a tablespace through the following tabs: *General*, *Definition*, *Parameters*, and *Security*. The *SQL* tab displays the SQL code generated by dialog selections. 
+
+.. image:: images/create_tablespace_general.png
+
+* Use the *Name* field to identify the tablespace with a descriptive name. The name cannot begin with pg\_; these names are reserved for system tablespaces. 
+* Select the owner of the tablespace from the drop-down listbox in the *Owner* field.
+* Store notes about the tablespace in the *Comments* field.  
+
+Click the *Definition* tab to continue.
+
+.. image:: images/create_tablespace_definition.png
+
+* Use the *Location* field to specify an absolute path to a directory that will contain the tablespace.
+
+Click the *Parameters* tab to continue.
+
+.. image:: images/create_tablespace_parameters.png
+
+Use the *Parameters* tab to set parameters for the tablespace:
+
+* Use the drop-down listbox next to *Parameter name* to select a parameter.
+* Click *Add* to add the parameter name to the table below.
+* Use the *Value* field to set a value for the parameter.
+
+Click *Add* to specify each additional parameter; to discard a parameter, click the trash icon to the left of the row and confirm deletion in the *Delete Row* dialog.
+
+Click the *Security* tab to continue.
+
+.. image:: images/create_tablespace_security.png
+
+Use the *Security* tab to assign privileges and define security labels. 
+
+Use the *Privileges* panel to assign security privileges to a role. Click *Add* to assign a set of privileges:
+
+* Select the name of the role from the drop-down listbox in the *Grantee* field.
+* Click inside the *Privileges* field. Check the boxes to the left of one or more privileges to grant the selected privileges to the specified user.
+* Select the name of the role from the drop-down listbox in the *Grantor* field. The default grantor is the owner of the owner of the tablespace.
+
+To discard a privilege, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Use the *Security Labels* panel to define security labels applied to the tablespace. Click *Add* to add each security label selection: 
+
+* Specify a security label provider in the *Provider* field. The named provider must be loaded and must consent to the proposed labeling operation.
+* Specify a a security label in the *Security Label* field. The meaning of a given label is at the discretion of the label provider. PostgreSQL places no restrictions on whether or how a label provider must interpret security labels; it merely provides a mechanism for storing them. 
+
+To discard a security label, click the trash icon to the left of the row and confirm deletion in the *Delete Row* popup.
+
+Click the *SQL* tab to continue.
+
+.. image:: images/create_tablespace_sql.png
+
+Your entries in the *Create - Tablespace* dialog generate a SQL command; you can review the command on the *SQL* pane.
+ 
+* Click the *Info* button (i) to access online help. 
+* Click the *Save* button to save work.
+* Click the *Cancel* button to exit without saving work.
+* Click the *Reset* button to restore configuration parameters.
+
+Example
+=======
+
+The following is an example of the sql command generated by user selections in the *Create - Tablespace* dialog: 
+
+.. image:: images/create_tablespace_sql_example.png
+
